Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/hand.py
diff options
context:
space:
mode:
authorWalter Bender <walter.bender@gmail.com>2011-03-15 01:35:40 (GMT)
committer Walter Bender <walter.bender@gmail.com>2011-03-15 01:35:40 (GMT)
commitf84386784d4f447fb20b00bceb5f2f731e45c65b (patch)
treee4395390c5ccc9510eeae089135129987e6ee2d1 /hand.py
parent0279518276390439777a351a770c9e98b23d6ab3 (diff)
on the path to sharing
Diffstat (limited to 'hand.py')
-rw-r--r--hand.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/hand.py b/hand.py
index 7b99b26..8264be9 100644
--- a/hand.py
+++ b/hand.py
@@ -22,17 +22,17 @@ CARDS = 3
class Hand:
''' Class for managing COL matrix of cards '''
- def __init__(self, card_width, card_height, robot=False):
+ def __init__(self, card_width, card_height, remote=False):
# the tiles in your hand
self.hand = []
- self.robot = robot # Does this hand belong to the robot?
+ self.remote = remote # Does this hand belong to someone remote?
for i in range(COL):
self.hand.append(None)
# card spacing
self.xinc = int(card_width)
- if self.robot:
+ if self.remote:
self.left = -self.xinc
else:
self.left = int(card_width / 2)